==> backend-naive-0.1.0-20170828.144048-3.jar: public/js/out/orcl/naive/impl.js <==
// Compiled by ClojureScript 1.9.908 {}
goog.provide('orcl.naive.impl');
goog.require('cljs.core');
goog.require('orcl.utils');
goog.require('orcl.naive.vars');
orcl.naive.impl.pending_res = (function orcl$naive$impl$pending_res(p){
var G__36909 = new cljs.core.Keyword(null,"type","type",1174270348).cljs$core$IFn$_invoke$arity$1(p);
var G__36909__$1 = (((G__36909 instanceof cljs.core.Keyword))?G__36909.fqn:null);
switch (G__36909__$1) {
case "wildcard":
case "var":
case "const":
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386)], null);

break;
case "list":
case "tuple":
return cljs.core.mapcat.call(null,orcl.naive.impl.pending_res,new cljs.core.Keyword(null,"patterns","patterns",1164082024).cljs$core$IFn$_invoke$arity$1(p));

break;
case "record":
return cljs.core.mapcat.call(null,cljs.core.comp.call(null,orcl.naive.impl.pending_res,cljs.core.second),new cljs.core.Keyword(null,"pairs","pairs",614609779).cljs$core$IFn$_invoke$arity$1(p));

break;
case "cons":
return cljs.core.concat.call(null,orcl.naive.impl.pending_res.call(null,new cljs.core.Keyword(null,"head","head",-771383919).cljs$core$IFn$_invoke$arity$1(p)),orcl.naive.impl.pending_res.call(null,new cljs.core.Keyword(null,"tail","tail",-1146023564).cljs$core$IFn$_invoke$arity$1(p)));

break;
case "as":
return cljs.core.cons.call(null,new cljs.core.Keyword(null,"alias","alias",-2039751630).cljs$core$IFn$_invoke$arity$1(p),orcl.naive.impl.pending_res.call(null,new cljs.core.Keyword(null,"pattern","pattern",242135423).cljs$core$IFn$_invoke$arity$1(p)));

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__36909__$1)].join('')));

}
});
orcl.naive.impl.pattern_checker_STAR_ = (function orcl$naive$impl$pattern_checker_STAR_(p){
var G__36911 = new cljs.core.Keyword(null,"type","type",1174270348).cljs$core$IFn$_invoke$arity$1(p);
var G__36911__$1 = (((G__36911 instanceof cljs.core.Keyword))?G__36911.fqn:null);
switch (G__36911__$1) {
case "wildcard":
case "var":
return cljs.core.constantly.call(null,true);

break;
case "const":
return ((function (G__36911,G__36911__$1){
return (function (v){
return cljs.core._EQ_.call(null,v,new cljs.core.Keyword(null,"value","value",305978217).cljs$core$IFn$_invoke$arity$1(p));
});
;})(G__36911,G__36911__$1))

break;
case "list":
case "tuple":
var checkers = cljs.core.map.call(null,orcl.naive.impl.pattern_checker_STAR_,new cljs.core.Keyword(null,"patterns","patterns",1164082024).cljs$core$IFn$_invoke$arity$1(p));
return ((function (checkers,G__36911,G__36911__$1){
return (function (v){
return (cljs.core.sequential_QMARK_.call(null,v)) && (cljs.core._EQ_.call(null,cljs.core.count.call(null,v),cljs.core.count.call(null,checkers))) && (cljs.core.every_QMARK_.call(null,((function (checkers,G__36911,G__36911__$1){
return (function (p__36916){
var vec__36917 = p__36916;
var checker = cljs.core.nth.call(null,vec__36917,(0),null);
var v__$1 = cljs.core.nth.call(null,vec__36917,(1),null);
return checker.call(null,v__$1);
});})(checkers,G__36911,G__36911__$1))
,cljs.core.map.call(null,cljs.core.vector,checkers,v)));
});
;})(checkers,G__36911,G__36911__$1))

break;
case "record":
var checkers = cljs.core.map.call(null,cljs.core.comp.call(null,orcl.naive.impl.pattern_checker_STAR_,cljs.core.second),new cljs.core.Keyword(null,"pairs","pairs",614609779).cljs$core$IFn$_invoke$arity$1(p));
return ((function (checkers,G__36911,G__36911__$1){
return (function (v){
return (cljs.core.map_QMARK_.call(null,v)) && (cljs.core.every_QMARK_.call(null,((function (checkers,G__36911,G__36911__$1){
return (function (p__36927){
var vec__36928 = p__36927;
var checker = cljs.core.nth.call(null,vec__36928,(0),null);
var vec__36931 = cljs.core.nth.call(null,vec__36928,(1),null);
var k = cljs.core.nth.call(null,vec__36931,(0),null);
var _ = cljs.core.nth.call(null,vec__36931,(1),null);
return checker.call(null,cljs.core.get.call(null,v,k,new cljs.core.Keyword("orcl.naive.impl","not-found","orcl.naive.impl/not-found",1683468943)));
});})(checkers,G__36911,G__36911__$1))
,cljs.core.map.call(null,cljs.core.vector,checkers,new cljs.core.Keyword(null,"pairs","pairs",614609779).cljs$core$IFn$_invoke$arity$1(p))));
});
;})(checkers,G__36911,G__36911__$1))

break;
case "cons":
var head = orcl.naive.impl.pattern_checker_STAR_.call(null,new cljs.core.Keyword(null,"head","head",-771383919).cljs$core$IFn$_invoke$arity$1(p));
var tail = orcl.naive.impl.pattern_checker_STAR_.call(null,new cljs.core.Keyword(null,"tail","tail",-1146023564).cljs$core$IFn$_invoke$arity$1(p));
return ((function (head,tail,G__36911,G__36911__$1){
return (function (v){
var and__27977__auto__ = cljs.core.sequential_QMARK_.call(null,v);
if(and__27977__auto__){
var vec__36937 = v;
var seq__36938 = cljs.core.seq.call(null,vec__36937);
var first__36939 = cljs.core.first.call(null,seq__36938);
var seq__36938__$1 = cljs.core.next.call(null,seq__36938);
var x = first__36939;
var xs = seq__36938__$1;
var and__27977__auto____$1 = head.call(null,x);
if(cljs.core.truth_(and__27977__auto____$1)){
return tail.call(null,xs);
} else {
return and__27977__auto____$1;
}
} else {
return and__27977__auto__;
}
});
;})(head,tail,G__36911,G__36911__$1))

break;
case "as":
return orcl.naive.impl.pattern_checker_STAR_.call(null,new cljs.core.Keyword(null,"pattern","pattern",242135423).cljs$core$IFn$_invoke$arity$1(p));

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__36911__$1)].join('')));

}
});
orcl.naive.impl.pattern_checker = (function orcl$naive$impl$pattern_checker(p){
var f = orcl.naive.impl.pattern_checker_STAR_.call(null,p);
return ((function (f){
return (function (v){
var or__27989__auto__ = cljs.core._EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386),v);
if(or__27989__auto__){
return or__27989__auto__;
} else {
return f.call(null,v);
}
});
;})(f))
});
orcl.naive.impl.pattern_extractor_STAR_ = (function orcl$naive$impl$pattern_extractor_STAR_(p){
var G__36943 = new cljs.core.Keyword(null,"type","type",1174270348).cljs$core$IFn$_invoke$arity$1(p);
var G__36943__$1 = (((G__36943 instanceof cljs.core.Keyword))?G__36943.fqn:null);
switch (G__36943__$1) {
case "var":
return ((function (G__36943,G__36943__$1){
return (function (v){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [v], null);
});
;})(G__36943,G__36943__$1))

break;
case "wildcard":
case "const":
return ((function (G__36943,G__36943__$1){
return (function (v){
return null;
});
;})(G__36943,G__36943__$1))

break;
case "list":
case "tuple":
var extractors = cljs.core.map.call(null,orcl.naive.impl.pattern_extractor_STAR_,new cljs.core.Keyword(null,"patterns","patterns",1164082024).cljs$core$IFn$_invoke$arity$1(p));
return ((function (extractors,G__36943,G__36943__$1){
return (function (v){
return cljs.core.mapcat.call(null,((function (extractors,G__36943,G__36943__$1){
return (function (p1__36941_SHARP_,p2__36942_SHARP_){
return p1__36941_SHARP_.call(null,p2__36942_SHARP_);
});})(extractors,G__36943,G__36943__$1))
,extractors,v);
});
;})(extractors,G__36943,G__36943__$1))

break;
case "record":
var extractors = cljs.core.map.call(null,cljs.core.comp.call(null,orcl.naive.impl.pattern_extractor_STAR_,cljs.core.second),new cljs.core.Keyword(null,"pairs","pairs",614609779).cljs$core$IFn$_invoke$arity$1(p));
return ((function (extractors,G__36943,G__36943__$1){
return (function (v){
return cljs.core.mapcat.call(null,((function (extractors,G__36943,G__36943__$1){
return (function (e,p__36944){
var vec__36945 = p__36944;
var k = cljs.core.nth.call(null,vec__36945,(0),null);
var _ = cljs.core.nth.call(null,vec__36945,(1),null);
return e.call(null,cljs.core.get.call(null,v,k,new cljs.core.Keyword("orcl.naive.impl","not-found","orcl.naive.impl/not-found",1683468943)));
});})(extractors,G__36943,G__36943__$1))
,extractors,new cljs.core.Keyword(null,"pairs","pairs",614609779).cljs$core$IFn$_invoke$arity$1(p));
});
;})(extractors,G__36943,G__36943__$1))

break;
case "cons":
var head = orcl.naive.impl.pattern_extractor_STAR_.call(null,new cljs.core.Keyword(null,"head","head",-771383919).cljs$core$IFn$_invoke$arity$1(p));
var tail = orcl.naive.impl.pattern_extractor_STAR_.call(null,new cljs.core.Keyword(null,"tail","tail",-1146023564).cljs$core$IFn$_invoke$arity$1(p));
return ((function (head,tail,G__36943,G__36943__$1){
return (function (p__36948){
var vec__36949 = p__36948;
var seq__36950 = cljs.core.seq.call(null,vec__36949);
var first__36951 = cljs.core.first.call(null,seq__36950);
var seq__36950__$1 = cljs.core.next.call(null,seq__36950);
var x = first__36951;
var xs = seq__36950__$1;
return cljs.core.concat.call(null,head.call(null,x),tail.call(null,xs));
});
;})(head,tail,G__36943,G__36943__$1))

break;
case "as":
var e = orcl.naive.impl.pattern_extractor_STAR_.call(null,new cljs.core.Keyword(null,"pattern","pattern",242135423).cljs$core$IFn$_invoke$arity$1(p));
return ((function (e,G__36943,G__36943__$1){
return (function (v){
var extracted = e.call(null,v);
return cljs.core.cons.call(null,v,extracted);
});
;})(e,G__36943,G__36943__$1))

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__36943__$1)].join('')));

}
});
orcl.naive.impl.pattern_extractor = (function orcl$naive$impl$pattern_extractor(p){
var pending = orcl.naive.impl.pending_res.call(null,p);
var f = orcl.naive.impl.pattern_extractor_STAR_.call(null,p);
return ((function (pending,f){
return (function (v){
if(cljs.core._EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386),v)){
return pending;
} else {
return f.call(null,v);
}
});
;})(pending,f))
});
orcl.naive.impl.otherwise = (function orcl$naive$impl$otherwise(left,right){
var temp__4655__auto__ = cljs.core.seq.call(null,left.call(null));
if(temp__4655__auto__){
var v = temp__4655__auto__;
return v;
} else {
return right.call(null);
}
});
orcl.naive.impl.sequential = (function orcl$naive$impl$sequential(left,right){
return cljs.core.mapcat.call(null,right,left);
});
orcl.naive.impl.internal_block = (function orcl$naive$impl$internal_block(k){
var v = cljs.core.get.call(null,cljs.core.deref.call(null,new cljs.core.Keyword(null,"internal","internal",-854870097).cljs$core$IFn$_invoke$arity$1(orcl.naive.vars._STAR_state_STAR_)),k,new cljs.core.Keyword("orcl.naive.impl","not-found","orcl.naive.impl/not-found",1683468943));
if(cljs.core._EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","not-found","orcl.naive.impl/not-found",1683468943),v)){
cljs.core.swap_BANG_.call(null,new cljs.core.Keyword(null,"internal","internal",-854870097).cljs$core$IFn$_invoke$arity$1(orcl.naive.vars._STAR_state_STAR_),cljs.core.assoc,k,new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386));

return new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386);
} else {
return v;
}
});
orcl.naive.impl.internal_unblock = (function orcl$naive$impl$internal_unblock(k,v){
var prev = cljs.core.get.call(null,cljs.core.deref.call(null,new cljs.core.Keyword(null,"internal","internal",-854870097).cljs$core$IFn$_invoke$arity$1(orcl.naive.vars._STAR_state_STAR_)),k);
cljs.core.swap_BANG_.call(null,new cljs.core.Keyword(null,"internal","internal",-854870097).cljs$core$IFn$_invoke$arity$1(orcl.naive.vars._STAR_state_STAR_),cljs.core.assoc,k,v);

if(cljs.core._EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386),prev)){
return cljs.core.reset_BANG_.call(null,new cljs.core.Keyword(null,"rerun","rerun",-15982659).cljs$core$IFn$_invoke$arity$1(orcl.naive.vars._STAR_state_STAR_),true);
} else {
return null;
}
});
orcl.naive.impl.site_call = (function orcl$naive$impl$site_call(f){
return (function() { 
var G__36954__delegate = function (args){
var res = (function (){try{return cljs.core.apply.call(null,f,args);
}catch (e36953){if((e36953 instanceof orcl.naive.impl.Exception)){
var e = e36953;
cljs.core.prn.call(null,"Site exception",e);

return new cljs.core.Keyword("orcl.naive.impl","halt","orcl.naive.impl/halt",-6234235);
} else {
throw e36953;

}
}})();
if(cljs.core._EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","halt","orcl.naive.impl/halt",-6234235),res)){
return null;
} else {
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [res], null);
}
};
var G__36954 = function (var_args){
var args = null;
if (arguments.length > 0) {
var G__36955__i = 0, G__36955__a = new Array(arguments.length -  0);
while (G__36955__i < G__36955__a.length) {G__36955__a[G__36955__i] = arguments[G__36955__i + 0]; ++G__36955__i;}
  args = new cljs.core.IndexedSeq(G__36955__a,0,null);
} 
return G__36954__delegate.call(this,args);};
G__36954.cljs$lang$maxFixedArity = 0;
G__36954.cljs$lang$applyTo = (function (arglist__36956){
var args = cljs.core.seq(arglist__36956);
return G__36954__delegate(args);
});
G__36954.cljs$core$IFn$_invoke$arity$variadic = G__36954__delegate;
return G__36954;
})()
;
});

//# sourceMappingURL=impl.js.map?rel=1503590932816

==> backend-naive-0.1.0-20170829.144415-7.jar: public/js/out/orcl/naive/impl.js <==
// Compiled by ClojureScript 1.9.908 {}
goog.provide('orcl.naive.impl');
goog.require('cljs.core');
goog.require('orcl.utils');
goog.require('orcl.naive.vars');
orcl.naive.impl.pending_res = (function orcl$naive$impl$pending_res(p){
var G__29620 = new cljs.core.Keyword(null,"type","type",1174270348).cljs$core$IFn$_invoke$arity$1(p);
var G__29620__$1 = (((G__29620 instanceof cljs.core.Keyword))?G__29620.fqn:null);
switch (G__29620__$1) {
case "wildcard":
case "var":
case "const":
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386)], null);

break;
case "list":
case "tuple":
return cljs.core.mapcat.call(null,orcl.naive.impl.pending_res,new cljs.core.Keyword(null,"patterns","patterns",1164082024).cljs$core$IFn$_invoke$arity$1(p));

break;
case "record":
return cljs.core.mapcat.call(null,cljs.core.comp.call(null,orcl.naive.impl.pending_res,cljs.core.second),new cljs.core.Keyword(null,"pairs","pairs",614609779).cljs$core$IFn$_invoke$arity$1(p));

break;
case "cons":
return cljs.core.concat.call(null,orcl.naive.impl.pending_res.call(null,new cljs.core.Keyword(null,"head","head",-771383919).cljs$core$IFn$_invoke$arity$1(p)),orcl.naive.impl.pending_res.call(null,new cljs.core.Keyword(null,"tail","tail",-1146023564).cljs$core$IFn$_invoke$arity$1(p)));

break;
case "as":
return cljs.core.cons.call(null,new cljs.core.Keyword(null,"alias","alias",-2039751630).cljs$core$IFn$_invoke$arity$1(p),orcl.naive.impl.pending_res.call(null,new cljs.core.Keyword(null,"pattern","pattern",242135423).cljs$core$IFn$_invoke$arity$1(p)));

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__29620__$1)].join('')));

}
});
orcl.naive.impl.pattern_checker_STAR_ = (function orcl$naive$impl$pattern_checker_STAR_(p){
var G__29622 = new cljs.core.Keyword(null,"type","type",1174270348).cljs$core$IFn$_invoke$arity$1(p);
var G__29622__$1 = (((G__29622 instanceof cljs.core.Keyword))?G__29622.fqn:null);
switch (G__29622__$1) {
case "wildcard":
case "var":
return cljs.core.constantly.call(null,true);

break;
case "const":
return ((function (G__29622,G__29622__$1){
return (function (v){
return cljs.core._EQ_.call(null,v,new cljs.core.Keyword(null,"value","value",305978217).cljs$core$IFn$_invoke$arity$1(p));
});
;})(G__29622,G__29622__$1))

break;
case "list":
case "tuple":
var checkers = cljs.core.map.call(null,orcl.naive.impl.pattern_checker_STAR_,new cljs.core.Keyword(null,"patterns","patterns",1164082024).cljs$core$IFn$_invoke$arity$1(p));
return ((function (checkers,G__29622,G__29622__$1){
return (function (v){
return (cljs.core.sequential_QMARK_.call(null,v)) && (cljs.core._EQ_.call(null,cljs.core.count.call(null,v),cljs.core.count.call(null,checkers))) && (cljs.core.every_QMARK_.call(null,((function (checkers,G__29622,G__29622__$1){
return (function (p__29627){
var vec__29628 = p__29627;
var checker = cljs.core.nth.call(null,vec__29628,(0),null);
var v__$1 = cljs.core.nth.call(null,vec__29628,(1),null);
return checker.call(null,v__$1);
});})(checkers,G__29622,G__29622__$1))
,cljs.core.map.call(null,cljs.core.vector,checkers,v)));
});
;})(checkers,G__29622,G__29622__$1))

break;
case "record":
var checkers = cljs.core.map.call(null,cljs.core.comp.call(null,orcl.naive.impl.pattern_checker_STAR_,cljs.core.second),new cljs.core.Keyword(null,"pairs","pairs",614609779).cljs$core$IFn$_invoke$arity$1(p));
return ((function (checkers,G__29622,G__29622__$1){
return (function (v){
return (cljs.core.map_QMARK_.call(null,v)) && (cljs.core.every_QMARK_.call(null,((function (checkers,G__29622,G__29622__$1){
return (function (p__29638){
var vec__29639 = p__29638;
var checker = cljs.core.nth.call(null,vec__29639,(0),null);
var vec__29642 = cljs.core.nth.call(null,vec__29639,(1),null);
var k = cljs.core.nth.call(null,vec__29642,(0),null);
var _ = cljs.core.nth.call(null,vec__29642,(1),null);
return checker.call(null,cljs.core.get.call(null,v,k,new cljs.core.Keyword("orcl.naive.impl","not-found","orcl.naive.impl/not-found",1683468943)));
});})(checkers,G__29622,G__29622__$1))
,cljs.core.map.call(null,cljs.core.vector,checkers,new cljs.core.Keyword(null,"pairs","pairs",614609779).cljs$core$IFn$_invoke$arity$1(p))));
});
;})(checkers,G__29622,G__29622__$1))

break;
case "cons":
var head = orcl.naive.impl.pattern_checker_STAR_.call(null,new cljs.core.Keyword(null,"head","head",-771383919).cljs$core$IFn$_invoke$arity$1(p));
var tail = orcl.naive.impl.pattern_checker_STAR_.call(null,new cljs.core.Keyword(null,"tail","tail",-1146023564).cljs$core$IFn$_invoke$arity$1(p));
return ((function (head,tail,G__29622,G__29622__$1){
return (function (v){
var and__27977__auto__ = cljs.core.sequential_QMARK_.call(null,v);
if(and__27977__auto__){
var vec__29648 = v;
var seq__29649 = cljs.core.seq.call(null,vec__29648);
var first__29650 = cljs.core.first.call(null,seq__29649);
var seq__29649__$1 = cljs.core.next.call(null,seq__29649);
var x = first__29650;
var xs = seq__29649__$1;
var and__27977__auto____$1 = head.call(null,x);
if(cljs.core.truth_(and__27977__auto____$1)){
return tail.call(null,xs);
} else {
return and__27977__auto____$1;
}
} else {
return and__27977__auto__;
}
});
;})(head,tail,G__29622,G__29622__$1))

break;
case "as":
return orcl.naive.impl.pattern_checker_STAR_.call(null,new cljs.core.Keyword(null,"pattern","pattern",242135423).cljs$core$IFn$_invoke$arity$1(p));

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__29622__$1)].join('')));

}
});
orcl.naive.impl.pattern_checker = (function orcl$naive$impl$pattern_checker(p){
var f = orcl.naive.impl.pattern_checker_STAR_.call(null,p);
return ((function (f){
return (function (v){
var or__27989__auto__ = cljs.core._EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386),v);
if(or__27989__auto__){
return or__27989__auto__;
} else {
return f.call(null,v);
}
});
;})(f))
});
orcl.naive.impl.pattern_extractor_STAR_ = (function orcl$naive$impl$pattern_extractor_STAR_(p){
var G__29654 = new cljs.core.Keyword(null,"type","type",1174270348).cljs$core$IFn$_invoke$arity$1(p);
var G__29654__$1 = (((G__29654 instanceof cljs.core.Keyword))?G__29654.fqn:null);
switch (G__29654__$1) {
case "var":
return ((function (G__29654,G__29654__$1){
return (function (v){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [v], null);
});
;})(G__29654,G__29654__$1))

break;
case "wildcard":
case "const":
return ((function (G__29654,G__29654__$1){
return (function (v){
return null;
});
;})(G__29654,G__29654__$1))

break;
case "list":
case "tuple":
var extractors = cljs.core.map.call(null,orcl.naive.impl.pattern_extractor_STAR_,new cljs.core.Keyword(null,"patterns","patterns",1164082024).cljs$core$IFn$_invoke$arity$1(p));
return ((function (extractors,G__29654,G__29654__$1){
return (function (v){
return cljs.core.mapcat.call(null,((function (extractors,G__29654,G__29654__$1){
return (function (p1__29652_SHARP_,p2__29653_SHARP_){
return p1__29652_SHARP_.call(null,p2__29653_SHARP_);
});})(extractors,G__29654,G__29654__$1))
,extractors,v);
});
;})(extractors,G__29654,G__29654__$1))

break;
case "record":
var extractors = cljs.core.map.call(null,cljs.core.comp.call(null,orcl.naive.impl.pattern_extractor_STAR_,cljs.core.second),new cljs.core.Keyword(null,"pairs","pairs",614609779).cljs$core$IFn$_invoke$arity$1(p));
return ((function (extractors,G__29654,G__29654__$1){
return (function (v){
return cljs.core.mapcat.call(null,((function (extractors,G__29654,G__29654__$1){
return (function (e,p__29655){
var vec__29656 = p__29655;
var k = cljs.core.nth.call(null,vec__29656,(0),null);
var _ = cljs.core.nth.call(null,vec__29656,(1),null);
return e.call(null,cljs.core.get.call(null,v,k,new cljs.core.Keyword("orcl.naive.impl","not-found","orcl.naive.impl/not-found",1683468943)));
});})(extractors,G__29654,G__29654__$1))
,extractors,new cljs.core.Keyword(null,"pairs","pairs",614609779).cljs$core$IFn$_invoke$arity$1(p));
});
;})(extractors,G__29654,G__29654__$1))

break;
case "cons":
var head = orcl.naive.impl.pattern_extractor_STAR_.call(null,new cljs.core.Keyword(null,"head","head",-771383919).cljs$core$IFn$_invoke$arity$1(p));
var tail = orcl.naive.impl.pattern_extractor_STAR_.call(null,new cljs.core.Keyword(null,"tail","tail",-1146023564).cljs$core$IFn$_invoke$arity$1(p));
return ((function (head,tail,G__29654,G__29654__$1){
return (function (p__29659){
var vec__29660 = p__29659;
var seq__29661 = cljs.core.seq.call(null,vec__29660);
var first__29662 = cljs.core.first.call(null,seq__29661);
var seq__29661__$1 = cljs.core.next.call(null,seq__29661);
var x = first__29662;
var xs = seq__29661__$1;
return cljs.core.concat.call(null,head.call(null,x),tail.call(null,xs));
});
;})(head,tail,G__29654,G__29654__$1))

break;
case "as":
var e = orcl.naive.impl.pattern_extractor_STAR_.call(null,new cljs.core.Keyword(null,"pattern","pattern",242135423).cljs$core$IFn$_invoke$arity$1(p));
return ((function (e,G__29654,G__29654__$1){
return (function (v){
var extracted = e.call(null,v);
return cljs.core.cons.call(null,v,extracted);
});
;})(e,G__29654,G__29654__$1))

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__29654__$1)].join('')));

}
});
orcl.naive.impl.pattern_extractor = (function orcl$naive$impl$pattern_extractor(p){
var pending = orcl.naive.impl.pending_res.call(null,p);
var f = orcl.naive.impl.pattern_extractor_STAR_.call(null,p);
return ((function (pending,f){
return (function (v){
if(cljs.core._EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386),v)){
return pending;
} else {
return f.call(null,v);
}
});
;})(pending,f))
});
orcl.naive.impl.otherwise = (function orcl$naive$impl$otherwise(left,right){
var temp__4655__auto__ = cljs.core.seq.call(null,left.call(null));
if(temp__4655__auto__){
var v = temp__4655__auto__;
return v;
} else {
return right.call(null);
}
});
orcl.naive.impl.sequential = (function orcl$naive$impl$sequential(left,right){
return cljs.core.mapcat.call(null,right,cljs.core.filter.call(null,(function (p1__29664_SHARP_){
return cljs.core.not_EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386),p1__29664_SHARP_);
}),left));
});
orcl.naive.impl.internal_block = (function orcl$naive$impl$internal_block(k){
var v = cljs.core.get.call(null,cljs.core.deref.call(null,new cljs.core.Keyword(null,"internal","internal",-854870097).cljs$core$IFn$_invoke$arity$1(orcl.naive.vars._STAR_state_STAR_)),k,new cljs.core.Keyword("orcl.naive.impl","not-found","orcl.naive.impl/not-found",1683468943));
if(cljs.core._EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","not-found","orcl.naive.impl/not-found",1683468943),v)){
cljs.core.swap_BANG_.call(null,new cljs.core.Keyword(null,"internal","internal",-854870097).cljs$core$IFn$_invoke$arity$1(orcl.naive.vars._STAR_state_STAR_),cljs.core.assoc,k,new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386));

return new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386);
} else {
return v;
}
});
orcl.naive.impl.internal_unblock = (function orcl$naive$impl$internal_unblock(k,v){
var prev = cljs.core.get.call(null,cljs.core.deref.call(null,new cljs.core.Keyword(null,"internal","internal",-854870097).cljs$core$IFn$_invoke$arity$1(orcl.naive.vars._STAR_state_STAR_)),k);
cljs.core.swap_BANG_.call(null,new cljs.core.Keyword(null,"internal","internal",-854870097).cljs$core$IFn$_invoke$arity$1(orcl.naive.vars._STAR_state_STAR_),cljs.core.assoc,k,v);

if(cljs.core._EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","pending","orcl.naive.impl/pending",-586847386),prev)){
return cljs.core.reset_BANG_.call(null,new cljs.core.Keyword(null,"rerun","rerun",-15982659).cljs$core$IFn$_invoke$arity$1(orcl.naive.vars._STAR_state_STAR_),true);
} else {
return null;
}
});
orcl.naive.impl.site_call = (function orcl$naive$impl$site_call(f){
return (function() { 
var G__29666__delegate = function (args){
var res = (function (){try{return cljs.core.apply.call(null,f,args);
}catch (e29665){if((e29665 instanceof Error)){
var e = e29665;
cljs.core.prn.call(null,"Site exception",e);

return new cljs.core.Keyword("orcl.naive.impl","halt","orcl.naive.impl/halt",-6234235);
} else {
throw e29665;

}
}})();
if(cljs.core._EQ_.call(null,new cljs.core.Keyword("orcl.naive.impl","halt","orcl.naive.impl/halt",-6234235),res)){
return null;
} else {
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [res], null);
}
};
var G__29666 = function (var_args){
var args = null;
if (arguments.length > 0) {
var G__29667__i = 0, G__29667__a = new Array(arguments.length -  0);
while (G__29667__i < G__29667__a.length) {G__29667__a[G__29667__i] = arguments[G__29667__i + 0]; ++G__29667__i;}
  args = new cljs.core.IndexedSeq(G__29667__a,0,null);
} 
return G__29666__delegate.call(this,args);};
G__29666.cljs$lang$maxFixedArity = 0;
G__29666.cljs$lang$applyTo = (function (arglist__29668){
var args = cljs.core.seq(arglist__29668);
return G__29666__delegate(args);
});
G__29666.cljs$core$IFn$_invoke$arity$variadic = G__29666__delegate;
return G__29666;
})()
;
});

//# sourceMappingURL=impl.js.map?rel=1504016569320
